Module blaxel.core.client.models.job_execution_task_condition
=============================================================

Classes
-------

`JobExecutionTaskCondition(execution_reason: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, message: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, reason: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, severity: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, state: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Job execution task condition
    
    Attributes:
        execution_reason (Union[Unset, str]): Execution reason
        message (Union[Unset, str]): Condition message
        reason (Union[Unset, str]): Condition reason
        severity (Union[Unset, str]): Condition severity
        state (Union[Unset, str]): Condition state
        type_ (Union[Unset, str]): Condition type
    
    Method generated by attrs for class JobExecutionTaskCondition.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `execution_reason: blaxel.core.client.types.Unset | str`
    :

    `message: blaxel.core.client.types.Unset | str`
    :

    `reason: blaxel.core.client.types.Unset | str`
    :

    `severity: blaxel.core.client.types.Unset | str`
    :

    `state: blaxel.core.client.types.Unset | str`
    :

    `type_: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :